@@ -1,4 +1,4 @@
-from typing import TYPE_CHECKING, List, cast
+from typing import TYPE_CHECKING, List, Optional, cast
 
 from openapi_schema_pydantic.v3.v3_1_0.operation import Operation
 from openapi_schema_pydantic.v3.v3_1_0.path_item import PathItem
@@ -12,11 +12,14 @@ from starlite.openapi.responses import create_responses
 from starlite.openapi.utils import extract_tags_from_route_handler
 
 if TYPE_CHECKING:
+    from starlite.handlers import HTTPRouteHandler
     from starlite.plugins.base import PluginProtocol
     from starlite.routes import HTTPRoute
 
 
-def create_path_item(route: "HTTPRoute", create_examples: bool, plugins: List["PluginProtocol"]) -> PathItem:
+def create_path_item(
+    route: "HTTPRoute", create_examples: bool, plugins: List["PluginProtocol"], use_handler_docstrings: bool
+) -> PathItem:
     """
     Create a PathItem model for the given route parsing all http_methods into Operation Models
     """
@@ -45,7 +48,7 @@ def create_path_item(route: "HTTPRoute", create_examples: bool, plugins: List["P
                 operationId=route_handler.operation_id or handler_name,
                 tags=extract_tags_from_route_handler(route_handler),
                 summary=route_handler.summary,
-                description=route_handler.description,
+                description=get_description_for_handler(route_handler, use_handler_docstrings),
                 deprecated=route_handler.deprecated,
                 responses=create_responses(
                     route_handler=route_handler,
@@ -58,3 +61,21 @@ def create_path_item(route: "HTTPRoute", create_examples: bool, plugins: List["P
             )
             setattr(path_item, http_method.lower(), operation)
     return path_item
+
+
+def get_description_for_handler(route_handler: "HTTPRouteHandler", use_handler_docstrings: bool) -> Optional[str]:
+    """
+    Produces the operation description for the handler.
+
+    Args:
+        route_handler (HTTPRouteHandler)
+        use_handler_docstrings (bool): If `True` and `route_handler.description` is `None` returns docstring of wrapped
+            handler function.
+
+    Returns:
+        str | None
+    """
+    handler_description = route_handler.description
+    if handler_description is None and use_handler_docstrings:
+        return route_handler.fn.__doc__
+    return handler_description
