@@ -11,6 +11,7 @@ from typing import (
     TypeVar,
     Union,
     cast,
+    get_type_hints,
 )
 
 from openapi_schema_pydantic.v3.v3_1_0.header import Header
@@ -23,7 +24,7 @@ from starlette.requests import HTTPConnection
 from starlette.responses import Response as StarletteResponse
 from typing_extensions import Literal, Protocol, runtime_checkable
 
-from starlite.exceptions import HTTPException
+from starlite.exceptions import HTTPException, ImproperlyConfiguredException
 from starlite.response import Response
 
 try:
@@ -103,15 +104,23 @@ class Partial(Generic[T]):
         """
         Modifies a given T subclass of BaseModel to be all optional
         """
+        if not issubclass(item, BaseModel):
+            raise ImproperlyConfiguredException(f"Partial[{item}] must be a subclass of BaseModel")
         if not cls._models.get(item):
             field_definitions: Dict[str, Tuple[Any, None]] = {}
-            for field_name, field_type in item.__annotations__.items():
-                # we modify the field annotations to make it optional
-                if not isinstance(field_type, GenericAlias) or type(None) not in field_type.__args__:
-                    field_definitions[field_name] = (Optional[field_type], None)
+            # traverse the object's mro and get all annotations
+            # until we find a BaseModel.
+            for obj in item.mro():
+                if issubclass(obj, BaseModel):
+                    for field_name, field_type in get_type_hints(obj).items():
+                        # we modify the field annotations to make it optional
+                        if not isinstance(field_type, GenericAlias) or type(None) not in field_type.__args__:
+                            field_definitions[field_name] = (Optional[field_type], None)
+                        else:
+                            field_definitions[field_name] = (field_type, None)
                 else:
-                    field_definitions[field_name] = (field_type, None)
-                cls._models[item] = create_model("Partial" + item.__name__, **field_definitions)  # type: ignore
+                    break
+            cls._models[item] = create_model(f"Partial{item.__name__}", **field_definitions)  # type: ignore
         return cast(Type[T], cls._models.get(item))
 
 
